:Overview: A set of tools to help building or using sequana pipelines
:Status: Production
:Citation: Cokelaer et al, (2017), ‘Sequana’: a Set of Snakemake NGS pipelines, Journal of Open Source Software, 2(16), 352, JOSS DOI doi:10.21105/joss.00352


Installation
~~~~~~~~~~~~

from pypi website::

    pip install sequana_pipetools

No dependencies for this package except Python itself. Although, when using it,
you will need to install the relevant Sequana pipelines that you wish to use. 

Changelog
~~~~~~~~~

========= ====================================================================
Version   Description
========= ====================================================================
0.1.0     creation of the package
========= ====================================================================
